/*=============================================================================
    Copyright (c) 2001-2010 Joel de Guzman
    Copyright (c) 2001-2010 Hartmut Kaiser
    http://spirit.sourceforge.net/

    Distributed under the Boost Software License, Version 1.0. (See accompanying
    file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
=============================================================================*/
#ifndef BOOST_SPIRIT_INCLUDE_QI_DIRECTIVE
#define BOOST_SPIRIT_INCLUDE_QI_DIRECTIVE

#if defined(_MSC_VER)
#pragma once
#endif

#include <boost/spirit/home/qi/directive.hpp>

#endif
